==> jc-1.4.0.tar.gz: polyglot/visit/FlowGraph__24Edge.h <==
// public class polyglot.visit.FlowGraph$Edge

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5bddfe710e5aba30 polyglot_visit_FlowGraph__24Edge

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_visit_FlowGraph__24Edge_H_
#define _JC_polyglot_visit_FlowGraph__24Edge_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_visit_FlowGraph__24EdgeKey$object;
struct _jc_polyglot_visit_FlowGraph__24Peer$object;

// Typedefs
typedef struct _jc_polyglot_visit_FlowGraph__24Edge$sub_refs	_jc_polyglot_visit_FlowGraph__24Edge$sub_refs;
typedef struct _jc_polyglot_visit_FlowGraph__24Edge$sub_nonrefs	_jc_polyglot_visit_FlowGraph__24Edge$sub_nonrefs;
typedef struct _jc_polyglot_visit_FlowGraph__24Edge$refs	_jc_polyglot_visit_FlowGraph__24Edge$refs;
typedef struct _jc_polyglot_visit_FlowGraph__24Edge$nonrefs	_jc_polyglot_visit_FlowGraph__24Edge$nonrefs;
typedef struct _jc_polyglot_visit_FlowGraph__24Edge$object	_jc_polyglot_visit_FlowGraph__24Edge$object;

typedef const struct _jc_polyglot_visit_FlowGraph__24Edge$vmethods	_jc_polyglot_visit_FlowGraph__24Edge$vmethods;
typedef const struct _jc_polyglot_visit_FlowGraph__24Edge$vtable	_jc_polyglot_visit_FlowGraph__24Edge$vtable;
typedef const struct _jc_polyglot_visit_FlowGraph__24Edge$vtype	_jc_polyglot_visit_FlowGraph__24Edge$vtype;

// Constructors
extern void _jc_polyglot_visit_FlowGraph__24Edge$method$_init$4cde9a52005968c1(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24Edge$object *, struct _jc_polyglot_visit_FlowGraph__24EdgeKey$object *, struct _jc_polyglot_visit_FlowGraph__24Peer$object *);

// Virtual methods
extern struct _jc_polyglot_visit_FlowGraph__24EdgeKey$object *_jc_polyglot_visit_FlowGraph__24Edge$method$getKey$db3f960072600eb1(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24Edge$object *);
extern struct _jc_polyglot_visit_FlowGraph__24Peer$object *_jc_polyglot_visit_FlowGraph__24Edge$method$getTarget$bab5d3ac6599966f(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24Edge$object *);
extern struct _jc_java_lang_String$object *_jc_polyglot_visit_FlowGraph__24Edge$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24Edge$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_visit_FlowGraph__24Edge$method_info$getKey$db3f960072600eb1;
extern _jc_method _jc_polyglot_visit_FlowGraph__24Edge$method_info$getTarget$bab5d3ac6599966f;
extern _jc_method _jc_polyglot_visit_FlowGraph__24Edge$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_polyglot_visit_FlowGraph__24Edge$vmethods {
	struct _jc_polyglot_visit_FlowGraph__24EdgeKey$object	*(*getKey$db3f960072600eb1)(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24Edge$object *);
	struct _jc_polyglot_visit_FlowGraph__24Peer$object	*(*getTarget$bab5d3ac6599966f)(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24Edge$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24Edge$object *);
};

// Vtable
struct _jc_polyglot_visit_FlowGraph__24Edge$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_FlowGraph__24Edge$vmethods	polyglot_visit_FlowGraph__24Edge;
};

// Vtype
struct _jc_polyglot_visit_FlowGraph__24Edge$vtype {
	_jc_type			type;
	_jc_polyglot_visit_FlowGraph__24Edge$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_FlowGraph__24Edge$sub_refs {
	struct _jc_polyglot_visit_FlowGraph__24EdgeKey$object	*key;
	struct _jc_polyglot_visit_FlowGraph__24Peer$object	*target;
};

// Reference instance fields (object)
struct _jc_polyglot_visit_FlowGraph__24Edge$refs {
    _jc_polyglot_visit_FlowGraph__24Edge$sub_refs	polyglot_visit_FlowGraph__24Edge;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_FlowGraph__24Edge$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_FlowGraph__24Edge$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_FlowGraph__24Edge$sub_nonrefs	polyglot_visit_FlowGraph__24Edge;
};

// Object instance structure
struct _jc_polyglot_visit_FlowGraph__24Edge$object {
	_jc_polyglot_visit_FlowGraph__24Edge$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_FlowGraph__24Edge$vtype	*vtype;
	_jc_polyglot_visit_FlowGraph__24Edge$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_FlowGraph__24Edge$vtype _jc_polyglot_visit_FlowGraph__24Edge$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_FlowGraph__24Edge, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_FlowGraph__24Edge$class_object;

#endif	/* _JC_polyglot_visit_FlowGraph__24Edge_H_ */

==> jc-1.4.6.tar.gz: polyglot/visit/FlowGraph__24Edge.h <==
// public class polyglot.visit.FlowGraph$Edge

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5bddfe710e5aba30 polyglot_visit_FlowGraph__24Edge

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_visit_FlowGraph__24Edge_H_
#define _JC_polyglot_visit_FlowGraph__24Edge_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_visit_FlowGraph__24EdgeKey$object;
struct _jc_polyglot_visit_FlowGraph__24Peer$object;

// Typedefs
typedef struct _jc_polyglot_visit_FlowGraph__24Edge$sub_refs	_jc_polyglot_visit_FlowGraph__24Edge$sub_refs;
typedef struct _jc_polyglot_visit_FlowGraph__24Edge$sub_nonrefs	_jc_polyglot_visit_FlowGraph__24Edge$sub_nonrefs;
typedef struct _jc_polyglot_visit_FlowGraph__24Edge$refs	_jc_polyglot_visit_FlowGraph__24Edge$refs;
typedef struct _jc_polyglot_visit_FlowGraph__24Edge$nonrefs	_jc_polyglot_visit_FlowGraph__24Edge$nonrefs;
typedef struct _jc_polyglot_visit_FlowGraph__24Edge$object	_jc_polyglot_visit_FlowGraph__24Edge$object;

typedef const struct _jc_polyglot_visit_FlowGraph__24Edge$vmethods	_jc_polyglot_visit_FlowGraph__24Edge$vmethods;
typedef const struct _jc_polyglot_visit_FlowGraph__24Edge$vtable	_jc_polyglot_visit_FlowGraph__24Edge$vtable;
typedef const struct _jc_polyglot_visit_FlowGraph__24Edge$vtype	_jc_polyglot_visit_FlowGraph__24Edge$vtype;

// Constructors
extern void _jc_polyglot_visit_FlowGraph__24Edge$method$_init$4cde9a52005968c1(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24Edge$object *, struct _jc_polyglot_visit_FlowGraph__24EdgeKey$object *, struct _jc_polyglot_visit_FlowGraph__24Peer$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_polyglot_visit_FlowGraph__24EdgeKey$object *_jc_polyglot_visit_FlowGraph__24Edge$method$getKey$db3f960072600eb1(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24Edge$object *) _JC_JCNI_ATTR;
extern struct _jc_polyglot_visit_FlowGraph__24Peer$object *_jc_polyglot_visit_FlowGraph__24Edge$method$getTarget$bab5d3ac6599966f(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24Edge$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_polyglot_visit_FlowGraph__24Edge$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24Edge$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_visit_FlowGraph__24Edge$method_info$getKey$db3f960072600eb1;
extern _jc_method _jc_polyglot_visit_FlowGraph__24Edge$method_info$getTarget$bab5d3ac6599966f;
extern _jc_method _jc_polyglot_visit_FlowGraph__24Edge$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_polyglot_visit_FlowGraph__24Edge$vmethods {
	struct _jc_polyglot_visit_FlowGraph__24EdgeKey$object	*(*getKey$db3f960072600eb1)(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24Edge$object *) _JC_JCNI_ATTR;
	struct _jc_polyglot_visit_FlowGraph__24Peer$object	*(*getTarget$bab5d3ac6599966f)(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24Edge$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24Edge$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_visit_FlowGraph__24Edge$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_FlowGraph__24Edge$vmethods	polyglot_visit_FlowGraph__24Edge;
};

// Vtype
struct _jc_polyglot_visit_FlowGraph__24Edge$vtype {
	_jc_type			type;
	_jc_polyglot_visit_FlowGraph__24Edge$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_FlowGraph__24Edge$sub_refs {
	struct _jc_polyglot_visit_FlowGraph__24EdgeKey$object	*key;
	struct _jc_polyglot_visit_FlowGraph__24Peer$object	*target;
};

// Reference instance fields (object)
struct _jc_polyglot_visit_FlowGraph__24Edge$refs {
    _jc_polyglot_visit_FlowGraph__24Edge$sub_refs	polyglot_visit_FlowGraph__24Edge;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_FlowGraph__24Edge$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_FlowGraph__24Edge$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_FlowGraph__24Edge$sub_nonrefs	polyglot_visit_FlowGraph__24Edge;
};

// Object instance structure
struct _jc_polyglot_visit_FlowGraph__24Edge$object {
	_jc_polyglot_visit_FlowGraph__24Edge$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_FlowGraph__24Edge$vtype	*vtype;
	_jc_polyglot_visit_FlowGraph__24Edge$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_FlowGraph__24Edge$vtype _jc_polyglot_visit_FlowGraph__24Edge$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_FlowGraph__24Edge, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_FlowGraph__24Edge$class_object;

#endif	/* _JC_polyglot_visit_FlowGraph__24Edge_H_ */
